# Recipe with ingredients

---

- *20 ml* water
- *1 cup* earl grey, hot
  - nested sublist
  - these items are not new ingredients, but part of the contents 
    of the top-level ingredient
    - same goes for deeper nesting
- *1 1/2 cup* coffee